# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/fairdatanow',
                'doc_host': 'https://fligt.github.io',
                'git_url': 'https://github.com/fligt/fairdatanow',
                'lib_path': 'fairdatanow'},
  'syms': { 'fairdatanow.webdav': { 'fairdatanow.webdav.RemoteData': ( 'exploring-your-remote-data.html#remotedata',
                                                                       'fairdatanow/webdav.py'),
                                    'fairdatanow.webdav.RemoteData.__init__': ( 'exploring-your-remote-data.html#remotedata.__init__',
                                                                                'fairdatanow/webdav.py'),
                                    'fairdatanow.webdav.RemoteData._reload_itable': ( 'exploring-your-remote-data.html#remotedata._reload_itable',
                                                                                      'fairdatanow/webdav.py'),
                                    'fairdatanow.webdav.RemoteData.check_exist': ( 'exploring-your-remote-data.html#remotedata.check_exist',
                                                                                   'fairdatanow/webdav.py'),
                                    'fairdatanow.webdav.RemoteData.delete': ( 'exploring-your-remote-data.html#remotedata.delete',
                                                                              'fairdatanow/webdav.py'),
                                    'fairdatanow.webdav.RemoteData.download': ( 'exploring-your-remote-data.html#remotedata.download',
                                                                                'fairdatanow/webdav.py'),
                                    'fairdatanow.webdav.RemoteData.download_selected': ( 'exploring-your-remote-data.html#remotedata.download_selected',
                                                                                         'fairdatanow/webdav.py'),
                                    'fairdatanow.webdav.RemoteData.listdir': ( 'exploring-your-remote-data.html#remotedata.listdir',
                                                                               'fairdatanow/webdav.py'),
                                    'fairdatanow.webdav.RemoteData.upload': ( 'exploring-your-remote-data.html#remotedata.upload',
                                                                              'fairdatanow/webdav.py'),
                                    'fairdatanow.webdav._node_to_dataframe': ( 'exploring-your-remote-data.html#_node_to_dataframe',
                                                                               'fairdatanow/webdav.py')}}}
